@@ -6,6 +6,7 @@ import numpy as np
 import ccp.config
 from scipy.optimize import newton
 from plotly import graph_objects as go
+from itertools import combinations
 from . import _RP
 
 from . import Q_
@@ -351,11 +352,25 @@ class State(CP.AbstractState):
         """
         Partial derivative of pressure to spec. volume with const. entropy.
         """
-        dpdv_s = Q_(
-            -self.rho().magnitude ** 2
-            * (self.first_partial_deriv(CP.iP, CP.iDmass, CP.iSmass)),
-            "pascal * kg / m**3",
-        )
+        try:
+            # dp/dv calculated from dp/drho needs to be multiplied by -rho**2
+            dpdv_s = Q_(
+                -self.rho().magnitude ** 2
+                * (self.first_partial_deriv(CP.iP, CP.iDmass, CP.iSmass)),
+                "pascal * kg / m**3",
+            )
+        except ValueError:
+            # manually calculate the derivative for REFPROP 9.1
+            dummy_state = copy(self)
+            p0 = self.p()
+            p1 = p0 + Q_(1e-1, "Pa")
+
+            dummy_state.update(p=p1, s=self.s())
+            v0 = self.v()
+            v1 = dummy_state.v()
+            dp = p1 - p0
+            dv = v1 - v0
+            dpdv_s = dp / dv
         if units:
             dpdv_s = dpdv_s.to(units)
         return dpdv_s
@@ -395,9 +410,23 @@ class State(CP.AbstractState):
 
         First partial derivative of temperature related to pressure with
         constant entropy."""
-        dTdp_s = Q_(
-            super().first_partial_deriv(CP.iT, CP.iP, CP.iSmass), "kelvin / pascal"
-        )
+        try:
+            dTdp_s = Q_(
+                super().first_partial_deriv(CP.iT, CP.iP, CP.iSmass), "kelvin / pascal"
+            )
+        except ValueError:
+            # manually calculate the derivative for REFPROP 9.1
+            dummy_state = copy(self)
+            p0 = self.p()
+            p1 = p0 + Q_(1e-1, "Pa")
+
+            dummy_state.update(p=p1, s=self.s())
+            T0 = self.T()
+            T1 = dummy_state.T()
+            dp = p1 - p0
+            dT = T1 - T0
+            dTdp_s = dT / dp
+
         if units:
             dTdp_s = dTdp_s.to(units)
 
@@ -504,7 +533,18 @@ class State(CP.AbstractState):
             # create an adequate fluid string to cp.AbstractState
         _fluid = "&".join(constituents)
 
-        state = cls(EOS, _fluid)
+        try:
+            state = cls(EOS, _fluid)
+        except ValueError:
+            error_msg = ""
+            for fluid1, fluid2 in combinations(constituents, 2):
+                try:
+                    fluid_pair = f"{fluid1}&{fluid2}"
+                    state = cls(EOS, fluid_pair)
+                except ValueError:
+                    error_msg += f"\nCould not create state with {fluid1} + {fluid2}"
+
+            raise ValueError(error_msg)
 
         normalize_mix(molar_fractions)
         state.set_mole_fractions(molar_fractions)
